import java.applet.Applet;
import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.Frame;
import java.awt.Insets;
import java.awt.Label;
import java.awt.Panel;

/**
   A class that can be used as either an applet or
   application.  

   <p>To use as an applet the init method creates the
   instance of the SimpleApp class to the applet panel.

   <p>To use as an application, the main function creates
   the necessary frame in which to place the SimpleApp
   instance.  
*/
public class SimpleApp extends Applet
{
  // Don't need a constructor.  Instead we build the applet
  // contents in the start() method.

  /**
     Specify the preferred size of this instance.

     @return the preferred size as a
     <code>java.awt.Dimension</code> object.
  */
  public Dimension getPreferredSize()
  {
    return new Dimension(350, 200);
  }

  public void init()
  {
    // Don't need to do anything here.  There is no browser
    // to call init() and start() for us when we run this as
    // an application.  Instead of building the contents of
    // the applet in the init() method, and calling both
    // init() and start(), we can simply put initialization
    // code in start() and call it, which is a simpler
    // approach.
  }


  /**
     Construct the contents of the applet.  This method can
     also be called explicitly in the main() function when
     running as an application.  This the reason we place
     the code here instead of in a constructor: we don't
     have to duplicate the same code.
  */
  public void start()
  {
    setLayout(new BorderLayout());

    Label label = new 
      Label("A program that's both an application and an applet.");

    add(label, BorderLayout.CENTER);
  }


  public void stop()
  {
    // Don't need to do any cleanup.
  }


  public void destroy()
  {
    // Don't need to do any cleanup.
  }


  /**
     Specifies the minimum amount of space between the edges
     of this container and the layout of any of its
     children.

     @return the Insets for this container.  
  */
  public Insets getInsets()
  {
    return new Insets(5, 20, 5, 20);
  }


  /**
     Creates the <code>Frame</code> needed to contain the
     instance of this class for running as an application.  
  */
  public static void main(String [] args)
  {
    // Because SimpleApp extends Applet, which is a Panel,
    // we can add it to a Frame.
    //
    SimpleApp app = new SimpleApp();

    // Call the applet's start() method, which builds its
    // contents.
    //
    app.start();

    // Create the Frame to hold the Applet, which is a type
    // of Panel.
    //
    Frame f = new Frame("A Simple Application");
    f.add(app);
    f.pack();
    f.setVisible(true);
  }


  SimpleApplet app; 
}
