import java.awt.BorderLayout;
import java.awt.Button;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.Font;
import java.awt.GridLayout;
import java.awt.Frame;
import java.awt.Label;
import java.awt.List;
import java.awt.Panel;
import java.awt.TextField;

/**
   A class that demonstrates the use of multiple nested
   containers to organize the location of its components.
*/
class MultipleContainers extends Frame
{
  /**
     No-arg constructor.
  */
  public MultipleContainers()
  {
    super("A frame with some components");
    setLayout(new GridLayout(4,1));

    Font font14 = new Font("SansSerif", Font.PLAIN, 14);
    Font font18 = new Font("SansSerif", Font.PLAIN, 18);

    // A Label component.
    //
    label = new Label("A simple label in a frame");
    label.setFont(font18);

    // Create a new container.  This is an internal
    // container nested inside the main application
    // container (the Frame).
    //
    Panel panel1 = new Panel();

    // Add the Label component to this container.
    panel1.add(label);
    
    // A Button component.
    //
    button = new Button("Push me");
    button.setFont(font14);

    // Create a second internal container.  Add the button
    // to this second panel.
    //
    Panel panel2 = new Panel();
    panel2.add(button);

    // A TextField component.
    //
    textField = new TextField("A text field");
    textField.setFont(font14);

    // Create a third internal container.  Add the text
    // field to it.
    //
    Panel panel3 = new Panel();
    panel3.add(textField);
    
    // Create and populate a List component.
    //
    list = new List(4);
    list.setFont(font14);
    list.add("Button");
    list.add("Canvas");
    list.add("Checkbox");
    list.add("Label");
    list.add("List");
    list.add("Scrollbar");
    list.add("ScrollPane");
    list.add("TextField");
    list.add("TextArea");

    // Create a fourth nested container.  Add the list to it.
    //
    Panel panel4 = new Panel();
    panel4.add(list);

    // Now add the four internal panels to our class instance.
    // This step creates the nesting.
    //
    add(panel1);
    add(panel2);
    add(panel3);
    add(panel4);

    // Notice that we create and add these two buttons to panel2
    // after we've added the other components to their panels. 
    // The buttons still show up on top of the text field and list
    // components on the GUI because they are added to a different
    // container, panel2, which is added to the application container
    // ahead of the panel that contains the text field.
    //
    Button button2 = new Button("Push me too");
    button2.setFont(font14);
    panel2.add(button2);

    Button button3 = new Button("Me first");
    button3.setFont(font14);
    panel2.add(button3);
  }

  public Dimension getPreferredSize()
  {
    return new Dimension(300, 300);
  }

  public static void main(String [] args)
  {
    MultipleContainers f = new MultipleContainers();
    f.pack();
    f.setVisible(true);
  }

  Button button;
  TextField textField;
  Label label;
  List list;
}
