import java.awt.*;

import javax.swing.*;
//import javax.swing.*;

/**
  This class builds a JInternalFrame inside of a JPanel, and creates a
  menu bar to place on the JInternalFrame.

  <p>This program is used here to demonstrate how to set the
  look-and-feel of your application.
  */
public class Layer1 extends JPanel
{
  /** 
    No-arg constructor.  
    */
  public Layer1()
  {
    // The JMenuBar that goes on the JInternalFrame.
    //
    JMenuBar menuBar = new JMenuBar();

    // The "File" menu.
    //
    JMenu file = new JMenu("File");

    // The "Edit" menu and its menu items.
    //
    JMenu edit = new JMenu("Edit");
    JMenuItem item1 = new JMenuItem("Undo");
    JMenuItem item2 = new JMenuItem("Cut");
    item2.setEnabled(false);
    JMenuItem item3 = new JMenuItem("Copy");
    item3.setEnabled(false);
    JMenuItem item4 = new JMenuItem("Paste");
    item4.setEnabled(false);
    JMenuItem item5 = new JMenuItem("Clear");
    item5.setEnabled(false);
    
    // Add the menu items to the "Edit" menu.
    //
    edit.add(item1);
    edit.add(item2);
    edit.add(item3);
    edit.add(item4);
    edit.add(item5);

    // The "Apps", "Options", "Buffers", and "Tools" menus.
    //
    JMenu apps = new JMenu("Apps");
    JMenu options = new JMenu("Options");
    JMenu buffers = new JMenu("Buffers");
    JMenu tools = new JMenu("Tools");

    // Add the menus to the menu bar.
    //
    menuBar.add(file);
    menuBar.add(edit);
    menuBar.add(apps);
    menuBar.add(options);
    menuBar.add(buffers);
    menuBar.add(tools);

    add(menuBar);

    // Create the JInternalFrame and add the menu bar to it.
    //
    JInternalFrame iFrame = new 
      JInternalFrame("An internal frame", true, true);
    iFrame.setPreferredSize(new Dimension(400, 300));
    iFrame.setJMenuBar(menuBar);
    add(iFrame);

    setVisible(true);
  }


  /**
    Specify a set preferred size for the JPanel.

    @return the predefined preferred size.

    */
  public Dimension getPreferredSize()
  {
    return new Dimension(450, 360);
  }


  public static void main(String [] args)
  {
    Layer1 app = new Layer1();

    // Set the l&f of the application.  The println() statements are
    // for demonstration.  You shouldn't put these in a real
    // application unless you are debugging.
    //
    try
      {
        UIManager.LookAndFeelInfo [] looks = 
          UIManager.getInstalledLookAndFeels();
        
        // Print out the fully qualified names of all the
        // looks-and-feels installed on the platform on which the
        // program is running.
        //
        for (int i = 0; i < looks.length; i++)
          {
            // Get the look-and-feel name in human readable form.
            //
            String name = looks[i].getName();

            // Get the look-and-feel in fully-qualified form.
            //
            String className = looks[i].getClassName();
            
//             System.out.println(name);
            System.out.println(className);
//             System.out.println();
          }

        // Print out the currently active look-and-feel.
        //
//         LookAndFeel currentLAF = UIManager.getLookAndFeel();
//         System.out.println(currentLAF);
//         System.out.println();

        // Set the specified look-and-feel.
        //
//         UIManager.setLookAndFeel(
//           "javax.swing.plaf.motif.MotifLookAndFeel");

        // Print out the name of the L&F just set, so we know if it
        // was set properly.
        //
//         System.out.println("The L&F just set is: ");
//         System.out.println(UIManager.getLookAndFeel());
      }
    catch (Exception e)
      {
        System.out.println(e.getMessage());
      }

    JFrame f = new JFrame("Changing the GUI's Look and Feel");
    Container contentPane = f.getContentPane();
    contentPane.add(app);
    f.pack();
    f.setVisible(true);
  }
}
